﻿namespace UploaderConfig
{
    partial class UploaderConfigDialog
    {
        /// <summary>
        /// 必要なデザイナ変数です。
        /// </summary>
        private System.ComponentModel.IContainer components = null;

        /// <summary>
        /// 使用中のリソースをすべてクリーンアップします。
        /// </summary>
        /// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null)) {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        #region Windows フォーム デザイナで生成されたコード

        /// <summary>
        /// デザイナ サポートに必要なメソッドです。このメソッドの内容を
        /// コード エディタで変更しないでください。
        /// </summary>
        private void InitializeComponent()
        {
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(UploaderConfigDialog));
            this.thumbDirPathLabel = new System.Windows.Forms.Label();
            this.adminTmplPathLabel = new System.Windows.Forms.Label();
            this.perPageItemNumberLabel = new System.Windows.Forms.Label();
            this.totalFileNumberLimitLabel = new System.Windows.Forms.Label();
            this.totalFileSizeLimitLabel = new System.Windows.Forms.Label();
            this.fileSizeLimitLabel = new System.Windows.Forms.Label();
            this.thumbnailTmplPathButton = new System.Windows.Forms.Button();
            this.pathLabel = new System.Windows.Forms.Label();
            this.modulePathLabel = new System.Windows.Forms.Label();
            this.baseUrlLabel = new System.Windows.Forms.Label();
            this.tempDirPathTextBox = new System.Windows.Forms.TextBox();
            this.uploaderConfigBindingSource = new System.Windows.Forms.BindingSource(this.components);
            this.dataDirPathLabel = new System.Windows.Forms.Label();
            this.fileDirPathLabel = new System.Windows.Forms.Label();
            this.tempDirPathLabel = new System.Windows.Forms.Label();
            this.indexTmplPathLabel = new System.Windows.Forms.Label();
            this.progressTmplPathLabel = new System.Windows.Forms.Label();
            this.downloadTmplPathLabel = new System.Windows.Forms.Label();
            this.thumbnailTmplPathLabel = new System.Windows.Forms.Label();
            this.configTabControl = new System.Windows.Forms.TabControl();
            this.tabPage1 = new System.Windows.Forms.TabPage();
            this.groupBox2 = new System.Windows.Forms.GroupBox();
            this.modulePathButton = new System.Windows.Forms.Button();
            this.modulePathTextBox = new System.Windows.Forms.TextBox();
            this.imagemagickPathButton = new System.Windows.Forms.Button();
            this.apachePathButton = new System.Windows.Forms.Button();
            this.apachePathTextBox = new System.Windows.Forms.TextBox();
            this.apachePathLabel = new System.Windows.Forms.Label();
            this.imagemagickPathLabel = new System.Windows.Forms.Label();
            this.imagemagickPathTextBox = new System.Windows.Forms.TextBox();
            this.groupBox3 = new System.Windows.Forms.GroupBox();
            this.pathTextBox = new System.Windows.Forms.TextBox();
            this.baseUrlTextBox = new System.Windows.Forms.TextBox();
            this.tabPage2 = new System.Windows.Forms.TabPage();
            this.thumbDirPathButton = new System.Windows.Forms.Button();
            this.thumbDirPathTextBox = new System.Windows.Forms.TextBox();
            this.tempDirPathButton = new System.Windows.Forms.Button();
            this.fileDirPathButton = new System.Windows.Forms.Button();
            this.dataDirPathButton = new System.Windows.Forms.Button();
            this.dataDirPathTextBox = new System.Windows.Forms.TextBox();
            this.fileDirPathTextBox = new System.Windows.Forms.TextBox();
            this.tabPage5 = new System.Windows.Forms.TabPage();
            this.javascriptDirPathButton = new System.Windows.Forms.Button();
            this.stylesheetDirPathButton = new System.Windows.Forms.Button();
            this.imageDirPathButton = new System.Windows.Forms.Button();
            this.javascriptDirPathLabel = new System.Windows.Forms.Label();
            this.javascriptDirPathTextBox = new System.Windows.Forms.TextBox();
            this.stylesheetDirPathLabel = new System.Windows.Forms.Label();
            this.stylesheetDirPathTextBox = new System.Windows.Forms.TextBox();
            this.imageDirPathLabel = new System.Windows.Forms.Label();
            this.imageDirPathTextBox = new System.Windows.Forms.TextBox();
            this.tabPage4 = new System.Windows.Forms.TabPage();
            this.totalFileSizeLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
            this.totalFileNumberLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
            this.perPageItemNumberNumericUpDown = new System.Windows.Forms.NumericUpDown();
            this.fileSizeLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
            this.tabPage3 = new System.Windows.Forms.TabPage();
            this.infoTmplPathButton = new System.Windows.Forms.Button();
            this.infoTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.infoTmplPathLabel = new System.Windows.Forms.Label();
            this.errorTmplPathLabel = new System.Windows.Forms.Label();
            this.errorTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.errorTmplPathButton = new System.Windows.Forms.Button();
            this.adminTmplPathButton = new System.Windows.Forms.Button();
            this.adminTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.downloadTmplPathButton = new System.Windows.Forms.Button();
            this.progressTmplPathButton = new System.Windows.Forms.Button();
            this.indexTmplPathButton = new System.Windows.Forms.Button();
            this.thumbnailTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.downloadTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.progressTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.indexTmplPathTextBox = new System.Windows.Forms.TextBox();
            this.errorProvider = new System.Windows.Forms.ErrorProvider(this.components);
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.apache_config_textTextBox = new System.Windows.Forms.TextBox();
            this.menuToolStrip = new System.Windows.Forms.ToolStrip();
            this.copyToolStripButton = new System.Windows.Forms.ToolStripButton();
            this.apacheStripButton = new System.Windows.Forms.ToolStripButton();
            this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
            this.helpStripButton = new System.Windows.Forms.ToolStripButton();
            this.copyButton = new System.Windows.Forms.Button();
            this.configTabControl.SuspendLayout();
            this.tabPage1.SuspendLayout();
            this.groupBox2.SuspendLayout();
            this.groupBox3.SuspendLayout();
            this.tabPage2.SuspendLayout();
            this.tabPage5.SuspendLayout();
            this.tabPage4.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.totalFileSizeLimitNumericUpDown)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.totalFileNumberLimitNumericUpDown)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.perPageItemNumberNumericUpDown)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).BeginInit();
            this.tabPage3.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).BeginInit();
            this.groupBox1.SuspendLayout();
            this.menuToolStrip.SuspendLayout();
            this.SuspendLayout();
            // 
            // thumbDirPathLabel
            // 
            this.thumbDirPathLabel.AutoSize = true;
            this.thumbDirPathLabel.Location = new System.Drawing.Point(8, 88);
            this.thumbDirPathLabel.Name = "thumbDirPathLabel";
            this.thumbDirPathLabel.Size = new System.Drawing.Size(141, 12);
            this.thumbDirPathLabel.TabIndex = 9;
            this.thumbDirPathLabel.Text = "サムネイルを保存するフォルダ";
            // 
            // adminTmplPathLabel
            // 
            this.adminTmplPathLabel.AutoSize = true;
            this.adminTmplPathLabel.Location = new System.Drawing.Point(8, 208);
            this.adminTmplPathLabel.Name = "adminTmplPathLabel";
            this.adminTmplPathLabel.Size = new System.Drawing.Size(123, 12);
            this.adminTmplPathLabel.TabIndex = 12;
            this.adminTmplPathLabel.Text = "管理ページのテンプレート";
            // 
            // perPageItemNumberLabel
            // 
            this.perPageItemNumberLabel.AutoSize = true;
            this.perPageItemNumberLabel.Location = new System.Drawing.Point(8, 128);
            this.perPageItemNumberLabel.Name = "perPageItemNumberLabel";
            this.perPageItemNumberLabel.Size = new System.Drawing.Size(173, 12);
            this.perPageItemNumberLabel.TabIndex = 2;
            this.perPageItemNumberLabel.Text = "1 ページあたりに表示するアイテム数";
            // 
            // totalFileNumberLimitLabel
            // 
            this.totalFileNumberLimitLabel.AutoSize = true;
            this.totalFileNumberLimitLabel.Location = new System.Drawing.Point(8, 88);
            this.totalFileNumberLimitLabel.Name = "totalFileNumberLimitLabel";
            this.totalFileNumberLimitLabel.Size = new System.Drawing.Size(107, 12);
            this.totalFileNumberLimitLabel.TabIndex = 4;
            this.totalFileNumberLimitLabel.Text = "ファイルの個数の上限";
            // 
            // totalFileSizeLimitLabel
            // 
            this.totalFileSizeLimitLabel.AutoSize = true;
            this.totalFileSizeLimitLabel.Location = new System.Drawing.Point(8, 48);
            this.totalFileSizeLimitLabel.Name = "totalFileSizeLimitLabel";
            this.totalFileSizeLimitLabel.Size = new System.Drawing.Size(169, 12);
            this.totalFileSizeLimitLabel.TabIndex = 6;
            this.totalFileSizeLimitLabel.Text = "ファイルサイズの合計の上限 （MB）";
            // 
            // fileSizeLimitLabel
            // 
            this.fileSizeLimitLabel.AutoSize = true;
            this.fileSizeLimitLabel.Location = new System.Drawing.Point(8, 8);
            this.fileSizeLimitLabel.Name = "fileSizeLimitLabel";
            this.fileSizeLimitLabel.Size = new System.Drawing.Size(249, 12);
            this.fileSizeLimitLabel.TabIndex = 0;
            this.fileSizeLimitLabel.Text = "一回にアップロードできるファイルの最大サイズ （MB）";
            // 
            // thumbnailTmplPathButton
            // 
            this.thumbnailTmplPathButton.Location = new System.Drawing.Point(384, 184);
            this.thumbnailTmplPathButton.Name = "thumbnailTmplPathButton";
            this.thumbnailTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.thumbnailTmplPathButton.TabIndex = 11;
            this.thumbnailTmplPathButton.Text = "参照";
            this.thumbnailTmplPathButton.UseVisualStyleBackColor = true;
            this.thumbnailTmplPathButton.Click += new System.EventHandler(this.thumbnailTmplPathButton_Click);
            // 
            // pathLabel
            // 
            this.pathLabel.AutoSize = true;
            this.pathLabel.Location = new System.Drawing.Point(8, 56);
            this.pathLabel.Name = "pathLabel";
            this.pathLabel.Size = new System.Drawing.Size(87, 12);
            this.pathLabel.TabIndex = 2;
            this.pathLabel.Text = "アップローダのパス";
            // 
            // modulePathLabel
            // 
            this.modulePathLabel.AutoSize = true;
            this.modulePathLabel.Location = new System.Drawing.Point(8, 16);
            this.modulePathLabel.Name = "modulePathLabel";
            this.modulePathLabel.Size = new System.Drawing.Size(120, 12);
            this.modulePathLabel.TabIndex = 6;
            this.modulePathLabel.Text = "mod_uploader.so のパス";
            // 
            // baseUrlLabel
            // 
            this.baseUrlLabel.AutoSize = true;
            this.baseUrlLabel.Location = new System.Drawing.Point(8, 16);
            this.baseUrlLabel.Name = "baseUrlLabel";
            this.baseUrlLabel.Size = new System.Drawing.Size(94, 12);
            this.baseUrlLabel.TabIndex = 0;
            this.baseUrlLabel.Text = "アップローダの URL";
            this.baseUrlLabel.Validating += new System.ComponentModel.CancelEventHandler(this.baseUrlLabel_Validating);
            // 
            // tempDirPathTextBox
            // 
            this.tempDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "tempDirPath", true));
            this.tempDirPathTextBox.Location = new System.Drawing.Point(8, 144);
            this.tempDirPathTextBox.Name = "tempDirPathTextBox";
            this.tempDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.tempDirPathTextBox.TabIndex = 7;
            this.tempDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // dataDirPathLabel
            // 
            this.dataDirPathLabel.AutoSize = true;
            this.dataDirPathLabel.Location = new System.Drawing.Point(8, 8);
            this.dataDirPathLabel.Name = "dataDirPathLabel";
            this.dataDirPathLabel.Size = new System.Drawing.Size(120, 12);
            this.dataDirPathLabel.TabIndex = 0;
            this.dataDirPathLabel.Text = "データを保存するフォルダ";
            // 
            // fileDirPathLabel
            // 
            this.fileDirPathLabel.AutoSize = true;
            this.fileDirPathLabel.Location = new System.Drawing.Point(8, 48);
            this.fileDirPathLabel.Name = "fileDirPathLabel";
            this.fileDirPathLabel.Size = new System.Drawing.Size(126, 12);
            this.fileDirPathLabel.TabIndex = 3;
            this.fileDirPathLabel.Text = "ファイルを保存するフォルダ";
            // 
            // tempDirPathLabel
            // 
            this.tempDirPathLabel.AutoSize = true;
            this.tempDirPathLabel.Location = new System.Drawing.Point(8, 128);
            this.tempDirPathLabel.Name = "tempDirPathLabel";
            this.tempDirPathLabel.Size = new System.Drawing.Size(150, 12);
            this.tempDirPathLabel.TabIndex = 6;
            this.tempDirPathLabel.Text = "一時ファイルを保存するフォルダ";
            // 
            // indexTmplPathLabel
            // 
            this.indexTmplPathLabel.AutoSize = true;
            this.indexTmplPathLabel.Location = new System.Drawing.Point(8, 8);
            this.indexTmplPathLabel.Name = "indexTmplPathLabel";
            this.indexTmplPathLabel.Size = new System.Drawing.Size(123, 12);
            this.indexTmplPathLabel.TabIndex = 0;
            this.indexTmplPathLabel.Text = "トップページのテンプレート";
            // 
            // progressTmplPathLabel
            // 
            this.progressTmplPathLabel.AutoSize = true;
            this.progressTmplPathLabel.Location = new System.Drawing.Point(8, 88);
            this.progressTmplPathLabel.Name = "progressTmplPathLabel";
            this.progressTmplPathLabel.Size = new System.Drawing.Size(176, 12);
            this.progressTmplPathLabel.TabIndex = 3;
            this.progressTmplPathLabel.Text = "アップロード進捗ページのテンプレート";
            // 
            // downloadTmplPathLabel
            // 
            this.downloadTmplPathLabel.AutoSize = true;
            this.downloadTmplPathLabel.Location = new System.Drawing.Point(8, 128);
            this.downloadTmplPathLabel.Name = "downloadTmplPathLabel";
            this.downloadTmplPathLabel.Size = new System.Drawing.Size(154, 12);
            this.downloadTmplPathLabel.TabIndex = 6;
            this.downloadTmplPathLabel.Text = "ダウンロードページのテンプレート";
            // 
            // thumbnailTmplPathLabel
            // 
            this.thumbnailTmplPathLabel.AutoSize = true;
            this.thumbnailTmplPathLabel.Location = new System.Drawing.Point(8, 168);
            this.thumbnailTmplPathLabel.Name = "thumbnailTmplPathLabel";
            this.thumbnailTmplPathLabel.Size = new System.Drawing.Size(148, 12);
            this.thumbnailTmplPathLabel.TabIndex = 9;
            this.thumbnailTmplPathLabel.Text = "サムネイルページのテンプレート";
            // 
            // configTabControl
            // 
            this.configTabControl.Controls.Add(this.tabPage1);
            this.configTabControl.Controls.Add(this.tabPage2);
            this.configTabControl.Controls.Add(this.tabPage5);
            this.configTabControl.Controls.Add(this.tabPage4);
            this.configTabControl.Controls.Add(this.tabPage3);
            this.configTabControl.Location = new System.Drawing.Point(0, 32);
            this.configTabControl.Name = "configTabControl";
            this.configTabControl.SelectedIndex = 0;
            this.configTabControl.Size = new System.Drawing.Size(456, 320);
            this.configTabControl.TabIndex = 1;
            this.configTabControl.SelectedIndexChanged += new System.EventHandler(this.configTabControl_SelectedIndexChanged);
            // 
            // tabPage1
            // 
            this.tabPage1.AutoScroll = true;
            this.tabPage1.Controls.Add(this.groupBox2);
            this.tabPage1.Controls.Add(this.groupBox3);
            this.tabPage1.Location = new System.Drawing.Point(4, 21);
            this.tabPage1.Name = "tabPage1";
            this.tabPage1.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage1.Size = new System.Drawing.Size(448, 295);
            this.tabPage1.TabIndex = 0;
            this.tabPage1.Text = "基本設定";
            this.tabPage1.UseVisualStyleBackColor = true;
            // 
            // groupBox2
            // 
            this.groupBox2.Controls.Add(this.modulePathButton);
            this.groupBox2.Controls.Add(this.modulePathLabel);
            this.groupBox2.Controls.Add(this.modulePathTextBox);
            this.groupBox2.Controls.Add(this.imagemagickPathButton);
            this.groupBox2.Controls.Add(this.apachePathButton);
            this.groupBox2.Controls.Add(this.apachePathTextBox);
            this.groupBox2.Controls.Add(this.apachePathLabel);
            this.groupBox2.Controls.Add(this.imagemagickPathLabel);
            this.groupBox2.Controls.Add(this.imagemagickPathTextBox);
            this.groupBox2.Location = new System.Drawing.Point(8, 8);
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.Size = new System.Drawing.Size(432, 139);
            this.groupBox2.TabIndex = 8;
            this.groupBox2.TabStop = false;
            this.groupBox2.Text = "アプリケーション";
            // 
            // modulePathButton
            // 
            this.modulePathButton.Location = new System.Drawing.Point(368, 32);
            this.modulePathButton.Name = "modulePathButton";
            this.modulePathButton.Size = new System.Drawing.Size(56, 23);
            this.modulePathButton.TabIndex = 8;
            this.modulePathButton.Text = "参照";
            this.modulePathButton.UseVisualStyleBackColor = true;
            this.modulePathButton.Click += new System.EventHandler(this.modulePathButton_Click);
            // 
            // modulePathTextBox
            // 
            this.modulePathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "modulePath", true));
            this.modulePathTextBox.Location = new System.Drawing.Point(8, 32);
            this.modulePathTextBox.Name = "modulePathTextBox";
            this.modulePathTextBox.Size = new System.Drawing.Size(344, 19);
            this.modulePathTextBox.TabIndex = 7;
            this.modulePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            this.modulePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.modulePathTextBox_Validating);
            // 
            // imagemagickPathButton
            // 
            this.imagemagickPathButton.Location = new System.Drawing.Point(368, 112);
            this.imagemagickPathButton.Name = "imagemagickPathButton";
            this.imagemagickPathButton.Size = new System.Drawing.Size(56, 23);
            this.imagemagickPathButton.TabIndex = 5;
            this.imagemagickPathButton.Text = "参照";
            this.imagemagickPathButton.UseVisualStyleBackColor = true;
            this.imagemagickPathButton.Click += new System.EventHandler(this.imagemagickPathButton_Click);
            // 
            // apachePathButton
            // 
            this.apachePathButton.Location = new System.Drawing.Point(368, 72);
            this.apachePathButton.Name = "apachePathButton";
            this.apachePathButton.Size = new System.Drawing.Size(56, 23);
            this.apachePathButton.TabIndex = 2;
            this.apachePathButton.Text = "参照";
            this.apachePathButton.UseVisualStyleBackColor = true;
            this.apachePathButton.Click += new System.EventHandler(this.apachePathButton_Click);
            // 
            // apachePathTextBox
            // 
            this.apachePathTextBox.Location = new System.Drawing.Point(8, 72);
            this.apachePathTextBox.Name = "apachePathTextBox";
            this.apachePathTextBox.Size = new System.Drawing.Size(344, 19);
            this.apachePathTextBox.TabIndex = 1;
            this.apachePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            this.apachePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.apachePathTextBox_Validating);
            // 
            // apachePathLabel
            // 
            this.apachePathLabel.AutoSize = true;
            this.apachePathLabel.Location = new System.Drawing.Point(8, 56);
            this.apachePathLabel.Name = "apachePathLabel";
            this.apachePathLabel.Size = new System.Drawing.Size(76, 12);
            this.apachePathLabel.TabIndex = 0;
            this.apachePathLabel.Text = "Apache のパス";
            // 
            // imagemagickPathLabel
            // 
            this.imagemagickPathLabel.AutoSize = true;
            this.imagemagickPathLabel.Location = new System.Drawing.Point(8, 96);
            this.imagemagickPathLabel.Name = "imagemagickPathLabel";
            this.imagemagickPathLabel.Size = new System.Drawing.Size(108, 12);
            this.imagemagickPathLabel.TabIndex = 3;
            this.imagemagickPathLabel.Text = "ImageMagick  のパス";
            // 
            // imagemagickPathTextBox
            // 
            this.imagemagickPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "imagemagickPath", true));
            this.imagemagickPathTextBox.Location = new System.Drawing.Point(8, 112);
            this.imagemagickPathTextBox.Name = "imagemagickPathTextBox";
            this.imagemagickPathTextBox.Size = new System.Drawing.Size(344, 19);
            this.imagemagickPathTextBox.TabIndex = 4;
            this.imagemagickPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            this.imagemagickPathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.imagemagickPathTextBox_Validating);
            // 
            // groupBox3
            // 
            this.groupBox3.Controls.Add(this.pathLabel);
            this.groupBox3.Controls.Add(this.baseUrlLabel);
            this.groupBox3.Controls.Add(this.pathTextBox);
            this.groupBox3.Controls.Add(this.baseUrlTextBox);
            this.groupBox3.Location = new System.Drawing.Point(8, 152);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(432, 104);
            this.groupBox3.TabIndex = 0;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "設置場所";
            // 
            // pathTextBox
            // 
            this.pathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "path", true));
            this.pathTextBox.Location = new System.Drawing.Point(8, 72);
            this.pathTextBox.Name = "pathTextBox";
            this.pathTextBox.ReadOnly = true;
            this.pathTextBox.Size = new System.Drawing.Size(408, 19);
            this.pathTextBox.TabIndex = 3;
            // 
            // baseUrlTextBox
            // 
            this.baseUrlTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "baseUrl", true));
            this.baseUrlTextBox.Location = new System.Drawing.Point(8, 32);
            this.baseUrlTextBox.Name = "baseUrlTextBox";
            this.baseUrlTextBox.Size = new System.Drawing.Size(408, 19);
            this.baseUrlTextBox.TabIndex = 1;
            this.baseUrlTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            this.baseUrlTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.baseUrlLabel_Validating);
            // 
            // tabPage2
            // 
            this.tabPage2.AutoScroll = true;
            this.tabPage2.Controls.Add(this.thumbDirPathButton);
            this.tabPage2.Controls.Add(this.thumbDirPathLabel);
            this.tabPage2.Controls.Add(this.thumbDirPathTextBox);
            this.tabPage2.Controls.Add(this.tempDirPathButton);
            this.tabPage2.Controls.Add(this.fileDirPathButton);
            this.tabPage2.Controls.Add(this.dataDirPathButton);
            this.tabPage2.Controls.Add(this.dataDirPathTextBox);
            this.tabPage2.Controls.Add(this.tempDirPathLabel);
            this.tabPage2.Controls.Add(this.tempDirPathTextBox);
            this.tabPage2.Controls.Add(this.fileDirPathLabel);
            this.tabPage2.Controls.Add(this.fileDirPathTextBox);
            this.tabPage2.Controls.Add(this.dataDirPathLabel);
            this.tabPage2.Location = new System.Drawing.Point(4, 21);
            this.tabPage2.Name = "tabPage2";
            this.tabPage2.Padding = new System.Windows.Forms.Padding(3);
            this.tabPage2.Size = new System.Drawing.Size(448, 295);
            this.tabPage2.TabIndex = 1;
            this.tabPage2.Text = "フォルダ(1)";
            this.tabPage2.UseVisualStyleBackColor = true;
            // 
            // thumbDirPathButton
            // 
            this.thumbDirPathButton.Location = new System.Drawing.Point(384, 104);
            this.thumbDirPathButton.Name = "thumbDirPathButton";
            this.thumbDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.thumbDirPathButton.TabIndex = 11;
            this.thumbDirPathButton.Text = "参照";
            this.thumbDirPathButton.UseVisualStyleBackColor = true;
            this.thumbDirPathButton.Click += new System.EventHandler(this.thumbDirPathButton_Click);
            // 
            // thumbDirPathTextBox
            // 
            this.thumbDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "thumbDirPath", true));
            this.thumbDirPathTextBox.Location = new System.Drawing.Point(8, 104);
            this.thumbDirPathTextBox.Name = "thumbDirPathTextBox";
            this.thumbDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.thumbDirPathTextBox.TabIndex = 10;
            this.thumbDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // tempDirPathButton
            // 
            this.tempDirPathButton.Location = new System.Drawing.Point(384, 144);
            this.tempDirPathButton.Name = "tempDirPathButton";
            this.tempDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.tempDirPathButton.TabIndex = 8;
            this.tempDirPathButton.Text = "参照";
            this.tempDirPathButton.UseVisualStyleBackColor = true;
            this.tempDirPathButton.Click += new System.EventHandler(this.tempDirPathButton_Click);
            // 
            // fileDirPathButton
            // 
            this.fileDirPathButton.Location = new System.Drawing.Point(384, 64);
            this.fileDirPathButton.Name = "fileDirPathButton";
            this.fileDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.fileDirPathButton.TabIndex = 5;
            this.fileDirPathButton.Text = "参照";
            this.fileDirPathButton.UseVisualStyleBackColor = true;
            this.fileDirPathButton.Click += new System.EventHandler(this.fileDirPathButton_Click);
            // 
            // dataDirPathButton
            // 
            this.dataDirPathButton.Location = new System.Drawing.Point(384, 24);
            this.dataDirPathButton.Name = "dataDirPathButton";
            this.dataDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.dataDirPathButton.TabIndex = 2;
            this.dataDirPathButton.Text = "参照";
            this.dataDirPathButton.UseVisualStyleBackColor = true;
            this.dataDirPathButton.Click += new System.EventHandler(this.dataDirPathButton_Click);
            // 
            // dataDirPathTextBox
            // 
            this.dataDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "dataDirPath", true));
            this.dataDirPathTextBox.Location = new System.Drawing.Point(8, 24);
            this.dataDirPathTextBox.Name = "dataDirPathTextBox";
            this.dataDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.dataDirPathTextBox.TabIndex = 1;
            this.dataDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // fileDirPathTextBox
            // 
            this.fileDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "fileDirPath", true));
            this.fileDirPathTextBox.Location = new System.Drawing.Point(8, 64);
            this.fileDirPathTextBox.Name = "fileDirPathTextBox";
            this.fileDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.fileDirPathTextBox.TabIndex = 4;
            this.fileDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // tabPage5
            // 
            this.tabPage5.Controls.Add(this.javascriptDirPathButton);
            this.tabPage5.Controls.Add(this.stylesheetDirPathButton);
            this.tabPage5.Controls.Add(this.imageDirPathButton);
            this.tabPage5.Controls.Add(this.javascriptDirPathLabel);
            this.tabPage5.Controls.Add(this.javascriptDirPathTextBox);
            this.tabPage5.Controls.Add(this.stylesheetDirPathLabel);
            this.tabPage5.Controls.Add(this.stylesheetDirPathTextBox);
            this.tabPage5.Controls.Add(this.imageDirPathLabel);
            this.tabPage5.Controls.Add(this.imageDirPathTextBox);
            this.tabPage5.Location = new System.Drawing.Point(4, 21);
            this.tabPage5.Name = "tabPage5";
            this.tabPage5.Size = new System.Drawing.Size(448, 295);
            this.tabPage5.TabIndex = 4;
            this.tabPage5.Text = "フォルダ(2)";
            this.tabPage5.UseVisualStyleBackColor = true;
            // 
            // javascriptDirPathButton
            // 
            this.javascriptDirPathButton.Location = new System.Drawing.Point(384, 104);
            this.javascriptDirPathButton.Name = "javascriptDirPathButton";
            this.javascriptDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.javascriptDirPathButton.TabIndex = 26;
            this.javascriptDirPathButton.Text = "参照";
            this.javascriptDirPathButton.UseVisualStyleBackColor = true;
            // 
            // stylesheetDirPathButton
            // 
            this.stylesheetDirPathButton.Location = new System.Drawing.Point(384, 64);
            this.stylesheetDirPathButton.Name = "stylesheetDirPathButton";
            this.stylesheetDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.stylesheetDirPathButton.TabIndex = 23;
            this.stylesheetDirPathButton.Text = "参照";
            this.stylesheetDirPathButton.UseVisualStyleBackColor = true;
            // 
            // imageDirPathButton
            // 
            this.imageDirPathButton.Location = new System.Drawing.Point(384, 24);
            this.imageDirPathButton.Name = "imageDirPathButton";
            this.imageDirPathButton.Size = new System.Drawing.Size(56, 23);
            this.imageDirPathButton.TabIndex = 20;
            this.imageDirPathButton.Text = "参照";
            this.imageDirPathButton.UseVisualStyleBackColor = true;
            // 
            // javascriptDirPathLabel
            // 
            this.javascriptDirPathLabel.AutoSize = true;
            this.javascriptDirPathLabel.Location = new System.Drawing.Point(8, 88);
            this.javascriptDirPathLabel.Name = "javascriptDirPathLabel";
            this.javascriptDirPathLabel.Size = new System.Drawing.Size(81, 12);
            this.javascriptDirPathLabel.TabIndex = 24;
            this.javascriptDirPathLabel.Text = "スクリプトフォルダ";
            // 
            // javascriptDirPathTextBox
            // 
            this.javascriptDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "javascriptDirPath", true));
            this.javascriptDirPathTextBox.Location = new System.Drawing.Point(8, 104);
            this.javascriptDirPathTextBox.Name = "javascriptDirPathTextBox";
            this.javascriptDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.javascriptDirPathTextBox.TabIndex = 25;
            // 
            // stylesheetDirPathLabel
            // 
            this.stylesheetDirPathLabel.AutoSize = true;
            this.stylesheetDirPathLabel.Location = new System.Drawing.Point(8, 48);
            this.stylesheetDirPathLabel.Name = "stylesheetDirPathLabel";
            this.stylesheetDirPathLabel.Size = new System.Drawing.Size(104, 12);
            this.stylesheetDirPathLabel.TabIndex = 21;
            this.stylesheetDirPathLabel.Text = "スタイルシートフォルダ";
            // 
            // stylesheetDirPathTextBox
            // 
            this.stylesheetDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "stylesheetDirPath", true));
            this.stylesheetDirPathTextBox.Location = new System.Drawing.Point(8, 64);
            this.stylesheetDirPathTextBox.Name = "stylesheetDirPathTextBox";
            this.stylesheetDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.stylesheetDirPathTextBox.TabIndex = 22;
            // 
            // imageDirPathLabel
            // 
            this.imageDirPathLabel.AutoSize = true;
            this.imageDirPathLabel.Location = new System.Drawing.Point(8, 8);
            this.imageDirPathLabel.Name = "imageDirPathLabel";
            this.imageDirPathLabel.Size = new System.Drawing.Size(64, 12);
            this.imageDirPathLabel.TabIndex = 18;
            this.imageDirPathLabel.Text = "画像フォルダ";
            // 
            // imageDirPathTextBox
            // 
            this.imageDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "imageDirPath", true));
            this.imageDirPathTextBox.Location = new System.Drawing.Point(8, 24);
            this.imageDirPathTextBox.Name = "imageDirPathTextBox";
            this.imageDirPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.imageDirPathTextBox.TabIndex = 19;
            // 
            // tabPage4
            // 
            this.tabPage4.Controls.Add(this.totalFileSizeLimitLabel);
            this.tabPage4.Controls.Add(this.totalFileSizeLimitNumericUpDown);
            this.tabPage4.Controls.Add(this.totalFileNumberLimitLabel);
            this.tabPage4.Controls.Add(this.totalFileNumberLimitNumericUpDown);
            this.tabPage4.Controls.Add(this.perPageItemNumberLabel);
            this.tabPage4.Controls.Add(this.perPageItemNumberNumericUpDown);
            this.tabPage4.Controls.Add(this.fileSizeLimitLabel);
            this.tabPage4.Controls.Add(this.fileSizeLimitNumericUpDown);
            this.tabPage4.Location = new System.Drawing.Point(4, 21);
            this.tabPage4.Name = "tabPage4";
            this.tabPage4.Size = new System.Drawing.Size(448, 295);
            this.tabPage4.TabIndex = 3;
            this.tabPage4.Text = "ファイル";
            this.tabPage4.UseVisualStyleBackColor = true;
            // 
            // totalFileSizeLimitNumericUpDown
            // 
            this.totalFileSizeLimitNumericUpDown.DataBindings.Add(new System.Windows.Forms.Binding("Value", this.uploaderConfigBindingSource, "totalFileSizeLimit", true));
            this.totalFileSizeLimitNumericUpDown.Increment = new decimal(new int[] {
            10,
            0,
            0,
            0});
            this.totalFileSizeLimitNumericUpDown.Location = new System.Drawing.Point(8, 64);
            this.totalFileSizeLimitNumericUpDown.Maximum = new decimal(new int[] {
            1048576,
            0,
            0,
            0});
            this.totalFileSizeLimitNumericUpDown.Name = "totalFileSizeLimitNumericUpDown";
            this.totalFileSizeLimitNumericUpDown.Size = new System.Drawing.Size(120, 19);
            this.totalFileSizeLimitNumericUpDown.TabIndex = 7;
            this.totalFileSizeLimitNumericUpDown.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // totalFileNumberLimitNumericUpDown
            // 
            this.totalFileNumberLimitNumericUpDown.DataBindings.Add(new System.Windows.Forms.Binding("Value", this.uploaderConfigBindingSource, "totalFileNumberLimit", true));
            this.totalFileNumberLimitNumericUpDown.Location = new System.Drawing.Point(8, 104);
            this.totalFileNumberLimitNumericUpDown.Maximum = new decimal(new int[] {
            10000,
            0,
            0,
            0});
            this.totalFileNumberLimitNumericUpDown.Name = "totalFileNumberLimitNumericUpDown";
            this.totalFileNumberLimitNumericUpDown.Size = new System.Drawing.Size(120, 19);
            this.totalFileNumberLimitNumericUpDown.TabIndex = 5;
            this.totalFileNumberLimitNumericUpDown.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // perPageItemNumberNumericUpDown
            // 
            this.perPageItemNumberNumericUpDown.DataBindings.Add(new System.Windows.Forms.Binding("Value", this.uploaderConfigBindingSource, "perPageItemNumber", true));
            this.perPageItemNumberNumericUpDown.Location = new System.Drawing.Point(8, 144);
            this.perPageItemNumberNumericUpDown.Maximum = new decimal(new int[] {
            1000,
            0,
            0,
            0});
            this.perPageItemNumberNumericUpDown.Name = "perPageItemNumberNumericUpDown";
            this.perPageItemNumberNumericUpDown.Size = new System.Drawing.Size(120, 19);
            this.perPageItemNumberNumericUpDown.TabIndex = 3;
            this.perPageItemNumberNumericUpDown.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // fileSizeLimitNumericUpDown
            // 
            this.fileSizeLimitNumericUpDown.DataBindings.Add(new System.Windows.Forms.Binding("Value", this.uploaderConfigBindingSource, "fileSizeLimit", true));
            this.fileSizeLimitNumericUpDown.Increment = new decimal(new int[] {
            10,
            0,
            0,
            0});
            this.fileSizeLimitNumericUpDown.Location = new System.Drawing.Point(8, 24);
            this.fileSizeLimitNumericUpDown.Maximum = new decimal(new int[] {
            4096,
            0,
            0,
            0});
            this.fileSizeLimitNumericUpDown.Name = "fileSizeLimitNumericUpDown";
            this.fileSizeLimitNumericUpDown.Size = new System.Drawing.Size(120, 19);
            this.fileSizeLimitNumericUpDown.TabIndex = 1;
            this.fileSizeLimitNumericUpDown.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.fileSizeLimitNumericUpDown.ThousandsSeparator = true;
            // 
            // tabPage3
            // 
            this.tabPage3.AutoScroll = true;
            this.tabPage3.Controls.Add(this.infoTmplPathButton);
            this.tabPage3.Controls.Add(this.infoTmplPathTextBox);
            this.tabPage3.Controls.Add(this.infoTmplPathLabel);
            this.tabPage3.Controls.Add(this.errorTmplPathLabel);
            this.tabPage3.Controls.Add(this.errorTmplPathTextBox);
            this.tabPage3.Controls.Add(this.errorTmplPathButton);
            this.tabPage3.Controls.Add(this.adminTmplPathButton);
            this.tabPage3.Controls.Add(this.adminTmplPathLabel);
            this.tabPage3.Controls.Add(this.adminTmplPathTextBox);
            this.tabPage3.Controls.Add(this.thumbnailTmplPathButton);
            this.tabPage3.Controls.Add(this.downloadTmplPathButton);
            this.tabPage3.Controls.Add(this.progressTmplPathButton);
            this.tabPage3.Controls.Add(this.indexTmplPathButton);
            this.tabPage3.Controls.Add(this.thumbnailTmplPathLabel);
            this.tabPage3.Controls.Add(this.thumbnailTmplPathTextBox);
            this.tabPage3.Controls.Add(this.downloadTmplPathLabel);
            this.tabPage3.Controls.Add(this.downloadTmplPathTextBox);
            this.tabPage3.Controls.Add(this.progressTmplPathLabel);
            this.tabPage3.Controls.Add(this.progressTmplPathTextBox);
            this.tabPage3.Controls.Add(this.indexTmplPathLabel);
            this.tabPage3.Controls.Add(this.indexTmplPathTextBox);
            this.tabPage3.Location = new System.Drawing.Point(4, 21);
            this.tabPage3.Name = "tabPage3";
            this.tabPage3.Size = new System.Drawing.Size(448, 295);
            this.tabPage3.TabIndex = 2;
            this.tabPage3.Text = "テンプレート";
            this.tabPage3.UseVisualStyleBackColor = true;
            // 
            // infoTmplPathButton
            // 
            this.infoTmplPathButton.Location = new System.Drawing.Point(384, 64);
            this.infoTmplPathButton.Name = "infoTmplPathButton";
            this.infoTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.infoTmplPathButton.TabIndex = 21;
            this.infoTmplPathButton.Text = "参照";
            this.infoTmplPathButton.UseVisualStyleBackColor = true;
            this.infoTmplPathButton.Click += new System.EventHandler(this.infoTmplPathButton_Click);
            // 
            // infoTmplPathTextBox
            // 
            this.infoTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "infoTmplPath", true));
            this.infoTmplPathTextBox.Location = new System.Drawing.Point(8, 64);
            this.infoTmplPathTextBox.Name = "infoTmplPathTextBox";
            this.infoTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.infoTmplPathTextBox.TabIndex = 20;
            // 
            // infoTmplPathLabel
            // 
            this.infoTmplPathLabel.AutoSize = true;
            this.infoTmplPathLabel.Location = new System.Drawing.Point(8, 48);
            this.infoTmplPathLabel.Name = "infoTmplPathLabel";
            this.infoTmplPathLabel.Size = new System.Drawing.Size(200, 12);
            this.infoTmplPathLabel.TabIndex = 19;
            this.infoTmplPathLabel.Text = "アップロード完了通知ページのテンプレート";
            // 
            // errorTmplPathLabel
            // 
            this.errorTmplPathLabel.AutoSize = true;
            this.errorTmplPathLabel.Location = new System.Drawing.Point(8, 248);
            this.errorTmplPathLabel.Name = "errorTmplPathLabel";
            this.errorTmplPathLabel.Size = new System.Drawing.Size(126, 12);
            this.errorTmplPathLabel.TabIndex = 18;
            this.errorTmplPathLabel.Text = "エラーページのテンプレート";
            // 
            // errorTmplPathTextBox
            // 
            this.errorTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "errorTmplPath", true));
            this.errorTmplPathTextBox.Location = new System.Drawing.Point(8, 264);
            this.errorTmplPathTextBox.Name = "errorTmplPathTextBox";
            this.errorTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.errorTmplPathTextBox.TabIndex = 17;
            this.errorTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // errorTmplPathButton
            // 
            this.errorTmplPathButton.Location = new System.Drawing.Point(384, 264);
            this.errorTmplPathButton.Name = "errorTmplPathButton";
            this.errorTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.errorTmplPathButton.TabIndex = 15;
            this.errorTmplPathButton.Text = "参照";
            this.errorTmplPathButton.UseVisualStyleBackColor = true;
            this.errorTmplPathButton.Click += new System.EventHandler(this.errorTmplPathButton_Click);
            // 
            // adminTmplPathButton
            // 
            this.adminTmplPathButton.Location = new System.Drawing.Point(384, 224);
            this.adminTmplPathButton.Name = "adminTmplPathButton";
            this.adminTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.adminTmplPathButton.TabIndex = 14;
            this.adminTmplPathButton.Text = "参照";
            this.adminTmplPathButton.UseVisualStyleBackColor = true;
            // 
            // adminTmplPathTextBox
            // 
            this.adminTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "adminTmplPath", true));
            this.adminTmplPathTextBox.Location = new System.Drawing.Point(8, 224);
            this.adminTmplPathTextBox.Name = "adminTmplPathTextBox";
            this.adminTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.adminTmplPathTextBox.TabIndex = 13;
            this.adminTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // downloadTmplPathButton
            // 
            this.downloadTmplPathButton.Location = new System.Drawing.Point(384, 144);
            this.downloadTmplPathButton.Name = "downloadTmplPathButton";
            this.downloadTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.downloadTmplPathButton.TabIndex = 8;
            this.downloadTmplPathButton.Text = "参照";
            this.downloadTmplPathButton.UseVisualStyleBackColor = true;
            this.downloadTmplPathButton.Click += new System.EventHandler(this.downloadTmplPathButton_Click);
            // 
            // progressTmplPathButton
            // 
            this.progressTmplPathButton.Location = new System.Drawing.Point(384, 104);
            this.progressTmplPathButton.Name = "progressTmplPathButton";
            this.progressTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.progressTmplPathButton.TabIndex = 5;
            this.progressTmplPathButton.Text = "参照";
            this.progressTmplPathButton.UseVisualStyleBackColor = true;
            this.progressTmplPathButton.Click += new System.EventHandler(this.progressTmplPathButton_Click);
            // 
            // indexTmplPathButton
            // 
            this.indexTmplPathButton.Location = new System.Drawing.Point(384, 24);
            this.indexTmplPathButton.Name = "indexTmplPathButton";
            this.indexTmplPathButton.Size = new System.Drawing.Size(56, 23);
            this.indexTmplPathButton.TabIndex = 2;
            this.indexTmplPathButton.Text = "参照";
            this.indexTmplPathButton.UseVisualStyleBackColor = true;
            this.indexTmplPathButton.Click += new System.EventHandler(this.indexTmplPathButton_Click);
            // 
            // thumbnailTmplPathTextBox
            // 
            this.thumbnailTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "thumbnailTmplPath", true));
            this.thumbnailTmplPathTextBox.Location = new System.Drawing.Point(8, 184);
            this.thumbnailTmplPathTextBox.Name = "thumbnailTmplPathTextBox";
            this.thumbnailTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.thumbnailTmplPathTextBox.TabIndex = 10;
            this.thumbnailTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // downloadTmplPathTextBox
            // 
            this.downloadTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "downloadTmplPath", true));
            this.downloadTmplPathTextBox.Location = new System.Drawing.Point(8, 144);
            this.downloadTmplPathTextBox.Name = "downloadTmplPathTextBox";
            this.downloadTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.downloadTmplPathTextBox.TabIndex = 7;
            this.downloadTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // progressTmplPathTextBox
            // 
            this.progressTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "progressTmplPath", true));
            this.progressTmplPathTextBox.Location = new System.Drawing.Point(8, 104);
            this.progressTmplPathTextBox.Name = "progressTmplPathTextBox";
            this.progressTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.progressTmplPathTextBox.TabIndex = 4;
            this.progressTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // indexTmplPathTextBox
            // 
            this.indexTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "indexTmplPath", true));
            this.indexTmplPathTextBox.Location = new System.Drawing.Point(8, 24);
            this.indexTmplPathTextBox.Name = "indexTmplPathTextBox";
            this.indexTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
            this.indexTmplPathTextBox.TabIndex = 1;
            this.indexTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            // 
            // errorProvider
            // 
            this.errorProvider.BlinkStyle = System.Windows.Forms.ErrorBlinkStyle.NeverBlink;
            this.errorProvider.ContainerControl = this;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.apache_config_textTextBox);
            this.groupBox1.Location = new System.Drawing.Point(0, 400);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(456, 176);
            this.groupBox1.TabIndex = 3;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "Apache 用の設定";
            // 
            // apache_config_textTextBox
            // 
            this.apache_config_textTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "apacheConfigText", true));
            this.apache_config_textTextBox.Font = new System.Drawing.Font("ＭＳ ゴシック", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(128)));
            this.apache_config_textTextBox.Location = new System.Drawing.Point(8, 16);
            this.apache_config_textTextBox.Multiline = true;
            this.apache_config_textTextBox.Name = "apache_config_textTextBox";
            this.apache_config_textTextBox.ReadOnly = true;
            this.apache_config_textTextBox.ScrollBars = System.Windows.Forms.ScrollBars.Both;
            this.apache_config_textTextBox.Size = new System.Drawing.Size(440, 152);
            this.apache_config_textTextBox.TabIndex = 0;
            this.apache_config_textTextBox.WordWrap = false;
            // 
            // menuToolStrip
            // 
            this.menuToolStrip.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.copyToolStripButton,
            this.apacheStripButton,
            this.toolStripSeparator1,
            this.helpStripButton});
            this.menuToolStrip.Location = new System.Drawing.Point(0, 0);
            this.menuToolStrip.Name = "menuToolStrip";
            this.menuToolStrip.Size = new System.Drawing.Size(457, 25);
            this.menuToolStrip.TabIndex = 0;
            this.menuToolStrip.Text = "toolStrip1";
            // 
            // copyToolStripButton
            // 
            this.copyToolStripButton.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
            this.copyToolStripButton.Image = global::UploaderConfig.Properties.Resources.CopyHS;
            this.copyToolStripButton.ImageTransparentColor = System.Drawing.Color.Magenta;
            this.copyToolStripButton.Name = "copyToolStripButton";
            this.copyToolStripButton.Size = new System.Drawing.Size(23, 22);
            this.copyToolStripButton.Text = "設定をコピー";
            this.copyToolStripButton.Click += new System.EventHandler(this.copyToolStripButton_Click);
            // 
            // apacheStripButton
            // 
            this.apacheStripButton.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
            this.apacheStripButton.Image = ((System.Drawing.Image)(resources.GetObject("apacheStripButton.Image")));
            this.apacheStripButton.ImageTransparentColor = System.Drawing.Color.Magenta;
            this.apacheStripButton.Name = "apacheStripButton";
            this.apacheStripButton.Size = new System.Drawing.Size(23, 22);
            this.apacheStripButton.Text = "Apache フォルダを開く";
            this.apacheStripButton.ToolTipText = "Apache フォルダを開く";
            this.apacheStripButton.Click += new System.EventHandler(this.apacheStripButton_Click);
            // 
            // toolStripSeparator1
            // 
            this.toolStripSeparator1.Name = "toolStripSeparator1";
            this.toolStripSeparator1.Size = new System.Drawing.Size(6, 25);
            // 
            // helpStripButton
            // 
            this.helpStripButton.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
            this.helpStripButton.Image = global::UploaderConfig.Properties.Resources.Help;
            this.helpStripButton.ImageTransparentColor = System.Drawing.Color.Magenta;
            this.helpStripButton.Name = "helpStripButton";
            this.helpStripButton.Size = new System.Drawing.Size(23, 22);
            this.helpStripButton.Text = "マニュアルを表示";
            this.helpStripButton.Click += new System.EventHandler(this.helpStripButton_Click);
            // 
            // copyButton
            // 
            this.copyButton.BackColor = System.Drawing.SystemColors.Control;
            this.copyButton.Font = new System.Drawing.Font("MS UI Gothic", 11.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(128)));
            this.copyButton.Location = new System.Drawing.Point(0, 360);
            this.copyButton.Name = "copyButton";
            this.copyButton.Size = new System.Drawing.Size(456, 32);
            this.copyButton.TabIndex = 2;
            this.copyButton.Text = "設定をコピー";
            this.copyButton.UseVisualStyleBackColor = false;
            this.copyButton.Click += new System.EventHandler(this.copyButton_Click);
            // 
            // UploaderConfigDialog
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.ClientSize = new System.Drawing.Size(457, 578);
            this.Controls.Add(this.copyButton);
            this.Controls.Add(this.menuToolStrip);
            this.Controls.Add(this.groupBox1);
            this.Controls.Add(this.configTabControl);
            this.DoubleBuffered = true;
            this.MaximizeBox = false;
            this.Name = "UploaderConfigDialog";
            this.Text = "mod_uploader 設定情報生成ツール";
            this.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
            this.Load += new System.EventHandler(this.UploaderConfigDialog_Load);
            ((System.ComponentModel.ISupportInitialize)(this.uploaderConfigBindingSource)).EndInit();
            this.configTabControl.ResumeLayout(false);
            this.tabPage1.ResumeLayout(false);
            this.groupBox2.ResumeLayout(false);
            this.groupBox2.PerformLayout();
            this.groupBox3.ResumeLayout(false);
            this.groupBox3.PerformLayout();
            this.tabPage2.ResumeLayout(false);
            this.tabPage2.PerformLayout();
            this.tabPage5.ResumeLayout(false);
            this.tabPage5.PerformLayout();
            this.tabPage4.ResumeLayout(false);
            this.tabPage4.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.totalFileSizeLimitNumericUpDown)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.totalFileNumberLimitNumericUpDown)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.perPageItemNumberNumericUpDown)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).EndInit();
            this.tabPage3.ResumeLayout(false);
            this.tabPage3.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).EndInit();
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            this.menuToolStrip.ResumeLayout(false);
            this.menuToolStrip.PerformLayout();
            this.ResumeLayout(false);
            this.PerformLayout();

        }

        #endregion

        private System.Windows.Forms.TabControl configTabControl;
        private System.Windows.Forms.TabPage tabPage1;
        private System.Windows.Forms.TabPage tabPage2;
        private System.Windows.Forms.BindingSource uploaderConfigBindingSource;
        private System.Windows.Forms.TextBox fileDirPathTextBox;
        private System.Windows.Forms.GroupBox groupBox1;
        private System.Windows.Forms.TextBox apache_config_textTextBox;
        private System.Windows.Forms.TabPage tabPage3;
        private System.Windows.Forms.TextBox indexTmplPathTextBox;
        private System.Windows.Forms.TextBox thumbnailTmplPathTextBox;
        private System.Windows.Forms.TextBox downloadTmplPathTextBox;
        private System.Windows.Forms.TextBox progressTmplPathTextBox;
        private System.Windows.Forms.Button progressTmplPathButton;
        private System.Windows.Forms.Button indexTmplPathButton;
        private System.Windows.Forms.ErrorProvider errorProvider;
        private System.Windows.Forms.TextBox dataDirPathTextBox;
        private System.Windows.Forms.Label fileDirPathLabel;
        private System.Windows.Forms.Label tempDirPathLabel;
        private System.Windows.Forms.Label indexTmplPathLabel;
        private System.Windows.Forms.Label progressTmplPathLabel;
        private System.Windows.Forms.Label downloadTmplPathLabel;
        private System.Windows.Forms.Label thumbnailTmplPathLabel;
        private System.Windows.Forms.Button downloadTmplPathButton;
        private System.Windows.Forms.Button tempDirPathButton;
        private System.Windows.Forms.Button fileDirPathButton;
        private System.Windows.Forms.Button dataDirPathButton;
        private System.Windows.Forms.ToolStrip menuToolStrip;
        private System.Windows.Forms.ToolStripButton copyToolStripButton;
        private System.Windows.Forms.Label dataDirPathLabel;
        private System.Windows.Forms.TextBox tempDirPathTextBox;
        private System.Windows.Forms.Label imagemagickPathLabel;
        private System.Windows.Forms.Label apachePathLabel;
        private System.Windows.Forms.TextBox imagemagickPathTextBox;
        private System.Windows.Forms.TextBox apachePathTextBox;
        private System.Windows.Forms.GroupBox groupBox2;
        private System.Windows.Forms.Button imagemagickPathButton;
        private System.Windows.Forms.Button apachePathButton;
        private System.Windows.Forms.GroupBox groupBox3;
        private System.Windows.Forms.TextBox pathTextBox;
        private System.Windows.Forms.TextBox baseUrlTextBox;
        private System.Windows.Forms.Button copyButton;
        private System.Windows.Forms.Label baseUrlLabel;
        private System.Windows.Forms.Button modulePathButton;
        private System.Windows.Forms.TextBox modulePathTextBox;
        private System.Windows.Forms.Label modulePathLabel;
        private System.Windows.Forms.ToolStripSeparator toolStripSeparator1;
        private System.Windows.Forms.ToolStripButton helpStripButton;
        private System.Windows.Forms.Button thumbnailTmplPathButton;
        private System.Windows.Forms.Label pathLabel;
        private System.Windows.Forms.TabPage tabPage4;
        private System.Windows.Forms.NumericUpDown fileSizeLimitNumericUpDown;
        private System.Windows.Forms.Label fileSizeLimitLabel;
        private System.Windows.Forms.NumericUpDown totalFileSizeLimitNumericUpDown;
        private System.Windows.Forms.NumericUpDown totalFileNumberLimitNumericUpDown;
        private System.Windows.Forms.NumericUpDown perPageItemNumberNumericUpDown;
        private System.Windows.Forms.Label perPageItemNumberLabel;
        private System.Windows.Forms.Label totalFileNumberLimitLabel;
        private System.Windows.Forms.Label totalFileSizeLimitLabel;
        private System.Windows.Forms.Button adminTmplPathButton;
        private System.Windows.Forms.TextBox adminTmplPathTextBox;

        private System.Windows.Forms.Label adminTmplPathLabel;
        private System.Windows.Forms.Button thumbDirPathButton;
        private System.Windows.Forms.TextBox thumbDirPathTextBox;
        private System.Windows.Forms.TabPage tabPage5;
        private System.Windows.Forms.Button javascriptDirPathButton;
        private System.Windows.Forms.Button stylesheetDirPathButton;
        private System.Windows.Forms.Button imageDirPathButton;
        private System.Windows.Forms.Label javascriptDirPathLabel;
        private System.Windows.Forms.TextBox javascriptDirPathTextBox;
        private System.Windows.Forms.Label stylesheetDirPathLabel;
        private System.Windows.Forms.TextBox stylesheetDirPathTextBox;
        private System.Windows.Forms.Label imageDirPathLabel;
        private System.Windows.Forms.TextBox imageDirPathTextBox;
        private System.Windows.Forms.Label thumbDirPathLabel;
        private System.Windows.Forms.ToolStripButton apacheStripButton;
        private System.Windows.Forms.Label errorTmplPathLabel;
        private System.Windows.Forms.TextBox errorTmplPathTextBox;

        private System.Windows.Forms.Button errorTmplPathButton;
        private System.Windows.Forms.Label infoTmplPathLabel;
        private System.Windows.Forms.Button infoTmplPathButton;
        private System.Windows.Forms.TextBox infoTmplPathTextBox;
    }
}